==> cdktf-cdktf-provider-googleworkspace-0.0.1.tar.gz: package/lib/data-googleworkspace-privileges/index.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleworkspacePrivilegesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/googleworkspace/d/privileges#id DataGoogleworkspacePrivileges#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleworkspacePrivilegesItems {
}
export declare function dataGoogleworkspacePrivilegesItemsToTerraform(struct?: DataGoogleworkspacePrivilegesItems): any;
export declare class DataGoogleworkspacePrivilegesItemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleworkspacePrivilegesItems | undefined;
    set internalValue(value: DataGoogleworkspacePrivilegesItems | undefined);
    get etag(): string;
    get isOrgUnitScopable(): cdktf.IResolvable;
    get privilegeName(): string;
    get serviceId(): string;
    get serviceName(): string;
}
export declare class DataGoogleworkspacePrivilegesItemsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleworkspacePrivilegesItemsOutputReference;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/googleworkspace/d/privileges googleworkspace_privileges}
*/
export declare class DataGoogleworkspacePrivileges extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "googleworkspace_privileges";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/googleworkspace/d/privileges googleworkspace_privileges} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleworkspacePrivilegesConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleworkspacePrivilegesConfig);
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _items;
    get items(): DataGoogleworkspacePrivilegesItemsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-googleworkspace-5.0.0.tar.gz: package/lib/data-googleworkspace-privileges/index.d.ts <==
/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleworkspacePrivilegesConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/privileges#id DataGoogleworkspacePrivileges#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
}
export interface DataGoogleworkspacePrivilegesItems {
}
export declare function dataGoogleworkspacePrivilegesItemsToTerraform(struct?: DataGoogleworkspacePrivilegesItems): any;
export declare class DataGoogleworkspacePrivilegesItemsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataGoogleworkspacePrivilegesItems | undefined;
    set internalValue(value: DataGoogleworkspacePrivilegesItems | undefined);
    get etag(): string;
    get isOrgUnitScopable(): cdktf.IResolvable;
    get privilegeName(): string;
    get serviceId(): string;
    get serviceName(): string;
}
export declare class DataGoogleworkspacePrivilegesItemsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataGoogleworkspacePrivilegesItemsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/privileges googleworkspace_privileges}
*/
export declare class DataGoogleworkspacePrivileges extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "googleworkspace_privileges";
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/googleworkspace/0.7.0/docs/data-sources/privileges googleworkspace_privileges} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleworkspacePrivilegesConfig = {}
    */
    constructor(scope: Construct, id: string, config?: DataGoogleworkspacePrivilegesConfig);
    get etag(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _items;
    get items(): DataGoogleworkspacePrivilegesItemsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
